@@ -329,7 +329,8 @@ class TestPSenseParser(unittest.TestCase):
         self.assertEqual(df["vout1"].iloc[-1], 0.5)
         self.assertEqual(df["signal1"].iloc[-1], 5.29)
         self.assertEqual(
-            df["timestamp"].iloc[-1], pd.Timestamp("2018-07-23 16:28:08.229594946")
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2018-07-23 16:28:08.22").round(freq="s"),
         )
 
     def test_load_bwii_script(self):
@@ -342,7 +343,10 @@ class TestPSenseParser(unittest.TestCase):
         self.assertEqual(df["signal1"].iloc[-1], 1)
         self.assertEqual(df["vout2"].iloc[-1], 2)
         self.assertEqual(df["signal2"].iloc[-1], 3)
-        self.assertEqual(df["timestamp"].iloc[-1], pd.Timestamp("2019-03-04T13:08:54"))
+        self.assertEqual(
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2019-03-04T13:08:54"),
+        )
 
         self.assertTrue(df["enable1"].iloc[-1])
         self.assertTrue(df["enable2"].iloc[0])
@@ -357,7 +361,10 @@ class TestPSenseParser(unittest.TestCase):
         self.assertEqual(df["signal1"].iloc[-1], 1.76)
         self.assertEqual(df["vout2"].iloc[-1], 0)
         self.assertEqual(df["signal2"].iloc[-1], 0)
-        self.assertEqual(df["timestamp"].iloc[-1], pd.Timestamp("2019-03-04 16:37:42"))
+        self.assertEqual(
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2019-03-04 16:37:42"),
+        )
 
         start_time = "2019/01/01 12:00"
         self.assertTrue(self.parser.load_rawfile(testfile, start_time, False))
@@ -366,7 +373,10 @@ class TestPSenseParser(unittest.TestCase):
         self.assertEqual(df["signal1"].iloc[-1], 1.76)
         self.assertEqual(df["vout2"].iloc[-1], 0)
         self.assertEqual(df["signal2"].iloc[-1], 0)
-        self.assertEqual(df["timestamp"].iloc[-1], pd.Timestamp("2019-01-01 12:13:43"))
+        self.assertEqual(
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2019-01-01 12:13:43"),
+        )
 
         self.assertTrue(self.parser.load_rawfile(testfile, start_time, True))
         df = self.parser.data
@@ -374,7 +384,10 @@ class TestPSenseParser(unittest.TestCase):
         self.assertEqual(df["signal1"].iloc[-1], 1.76)
         self.assertEqual(df["vout2"].iloc[-1], 0)
         self.assertEqual(df["signal2"].iloc[-1], 0)
-        self.assertEqual(df["timestamp"].iloc[-1], pd.Timestamp("2019-01-01 12:00:00"))
+        self.assertEqual(
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2019-01-01 12:00:00"),
+        )
 
     def test_load_bwii_mini(self):
         testfile = "tests/bwii_mini_example"
@@ -394,7 +407,10 @@ class TestPSenseParser(unittest.TestCase):
         self.assertEqual(df["signal2"].iloc[-1], 0)
         self.assertEqual(df["vout3"].iloc[-1], -0.488)
         self.assertEqual(df["signal3"].iloc[-1], 0)
-        self.assertEqual(df["timestamp"].iloc[-1], pd.Timestamp("2020-01-01 19:32:17"))
+        self.assertEqual(
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2020-01-01 19:32:17"),
+        )
 
         self.assertTrue(df["enable1"].iloc[0])
         self.assertFalse(df["enable2"].iloc[0])
@@ -404,13 +420,23 @@ class TestPSenseParser(unittest.TestCase):
         start_time = "2019/01/01 12:00"
         self.assertTrue(self.parser.load_rawfile(testfile, start_time, False))
         df = self.parser.data
-        self.assertEqual(df["timestamp"].iloc[0], pd.Timestamp("2019-01-01 12:00:00"))
-        self.assertEqual(df["timestamp"].iloc[-1], pd.Timestamp("2019-01-01 12:02:19"))
+        self.assertEqual(
+            df["timestamp"].iloc[0].round(freq="s"), pd.Timestamp("2019-01-01 12:00:00")
+        )
+        self.assertEqual(
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2019-01-01 12:02:19"),
+        )
 
         self.assertTrue(self.parser.load_rawfile(testfile, start_time, True))
         df = self.parser.data
-        self.assertEqual(df["timestamp"].iloc[0], pd.Timestamp("2019-01-01 11:57:41"))
-        self.assertEqual(df["timestamp"].iloc[-1], pd.Timestamp("2019-01-01 12:00:00"))
+        self.assertEqual(
+            df["timestamp"].iloc[0].round(freq="s"), pd.Timestamp("2019-01-01 11:57:41")
+        )
+        self.assertEqual(
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2019-01-01 12:00:00"),
+        )
 
     def test_load_bwii_util(self):
         # files downloaded from BWII_Util.exe have extra whitespace. Make sure they are loaded properly
@@ -529,7 +555,10 @@ class TestPSenseParser(unittest.TestCase):
         self.assertEqual(df["signal2"].iloc[-1], 15)
         self.assertTrue(df["enable2"].iloc[-1])
 
-        self.assertEqual(df["timestamp"].iloc[-1], pd.Timestamp("2019-07-09 17:35:24"))
+        self.assertEqual(
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2019-07-09 17:35:24"),
+        )
 
         testfile = "tests/web3chan_example"
         self.parser.identify_file_source(testfile)
@@ -546,7 +575,10 @@ class TestPSenseParser(unittest.TestCase):
         self.assertEqual(df["signal2"].iloc[-1], 0.03)
         self.assertTrue(df["enable2"].iloc[-1])
 
-        self.assertEqual(df["timestamp"].iloc[-1], pd.Timestamp("2020-02-10 11:04:54"))
+        self.assertEqual(
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2020-02-10 11:04:54"),
+        )
 
     def test_load_vfp600(self):
         # vfp600
@@ -555,7 +587,10 @@ class TestPSenseParser(unittest.TestCase):
         self.parser.identify_file_source(testfile)
         self.assertTrue(self.parser.load_rawfile(testfile, start_time, False))
         df = self.parser.data
-        self.assertEqual(df["timestamp"].iloc[0], pd.Timestamp(start_time))
+        self.assertEqual(
+            df["timestamp"].iloc[0].round(freq="s"),
+            pd.Timestamp(start_time).round(freq="s"),
+        )
         self.assertTrue(self.parser.load_rawfile(testfile, start_time, True))
         df = self.parser.data
         self.assertTrue(df["timestamp"].iloc[0] < pd.Timestamp(start_time))
@@ -572,7 +607,10 @@ class TestPSenseParser(unittest.TestCase):
         self.parser.identify_file_source(testfile)
         self.assertTrue(self.parser.load_rawfile(testfile, start_time, False))
         df = self.parser.data
-        self.assertEqual(df["timestamp"].iloc[0], pd.Timestamp(start_time))
+        self.assertEqual(
+            df["timestamp"].iloc[0].round(freq="s"),
+            pd.Timestamp(start_time).round(freq="s"),
+        )
         self.assertTrue(self.parser.load_rawfile(testfile, start_time, True))
         df = self.parser.data
         self.assertTrue(df["timestamp"].iloc[0] < pd.Timestamp(start_time))
@@ -592,13 +630,19 @@ class TestPSenseParser(unittest.TestCase):
         self.parser.identify_file_source(testfile)
         self.assertTrue(self.parser.load_rawfile(testfile, start_time, False))
         df = self.parser.data
-        self.assertEqual(df["timestamp"].iloc[0], pd.Timestamp(start_time))
+        self.assertEqual(
+            df["timestamp"].iloc[0].round(freq="s"),
+            pd.Timestamp(start_time).round(freq="s"),
+        )
         self.assertTrue(self.parser.load_rawfile(testfile, start_time, True))
         df = self.parser.data
-        self.assertEqual(df["timestamp"].iloc[0], pd.Timestamp(start_time))
+        self.assertEqual(
+            df["timestamp"].iloc[0].round(freq="s"),
+            pd.Timestamp(start_time).round(freq="s"),
+        )
 
-        self.assertEqual(df["vout1"].iloc[-1], 0.499654)
-        self.assertEqual(df["signal1"].iloc[-1], 3.60525)
+        self.assertEqual(round(1000 * df["vout1"].iloc[-1]) / 1000, 0.500)
+        self.assertEqual(round(1000 * df["signal1"].iloc[-1]) / 1000, 3.605)
         self.assertTrue(df["enable1"].iloc[-1])
 
     def test_load_chinstruments(self):
@@ -608,8 +652,13 @@ class TestPSenseParser(unittest.TestCase):
         self.assertTrue(self.parser.load_rawfile(testfile, None, None))
         df = self.parser.data
 
-        self.assertEqual(df["timestamp"].iloc[0], pd.Timestamp("2020/07/15 15:27:12"))
-        self.assertEqual(df["timestamp"].iloc[-1], pd.Timestamp("2020/07/15 15:37:12"))
+        self.assertEqual(
+            df["timestamp"].iloc[0].round(freq="s"), pd.Timestamp("2020/07/15 15:27:12")
+        )
+        self.assertEqual(
+            df["timestamp"].iloc[-1].round(freq="s"),
+            pd.Timestamp("2020/07/15 15:37:12"),
+        )
 
         self.assertEqual(df["vout1"].iloc[0], 0.5)
         self.assertEqual(df["vout1"].iloc[-1], 0.5)
